Error

Enum Error 

pub enum Error {
Show 33 variants Storage(Error), Database(String), Table(String), Transaction(String), Commit(String), VectorIndex(String), InvalidFormat(&'static str), UnsupportedVersion(u32, u32), MemoryNotFound(String), EntityNotFound(String), InvalidEmbeddingDimension { expected: usize, got: usize, }, Serialization(String), Deserialization(String), Io(Error), InvalidMemoryId(String), InvalidTimestamp(String), InvalidSource(String), Configuration(String), InvalidParameter(String), DatabaseExists(String), DatabaseNotFound(String), NamespaceMismatch { expected: String, found: String, }, DatabaseCorruption(String), FileTruncated(String), SlmNotAvailable, SlmInitialization(String), SlmInference(String), SlmTimeout(u64), ModelNotFound(String), InferenceError(String), EntityExtractionNotAvailable, NoEmbeddingEngine, EmbeddingNotAvailable,
}
Main error type for MnemeFusion operations

Variants



Storage(Error)

Storage engine error (redb)



Database(String)

Database error



Table(String)

Table error



Transaction(String)

Storage transaction error



Commit(String)

Storage commit error



VectorIndex(String)

Vector index error



InvalidFormat(&'static str)

Invalid file format



UnsupportedVersion(u32, u32)

Unsupported version



MemoryNotFound(String)

Memory not found



EntityNotFound(String)

Entity not found



InvalidEmbeddingDimension

Invalid embedding dimension

Fields

expected: usize
got: usize


Serialization(String)

Serialization error



Deserialization(String)

Deserialization error



Io(Error)

IO error



InvalidMemoryId(String)

Invalid memory ID format



InvalidTimestamp(String)

Invalid timestamp



InvalidSource(String)

Invalid source



Configuration(String)

Configuration error



InvalidParameter(String)

Invalid parameter



DatabaseExists(String)

Database already exists



DatabaseNotFound(String)

Database not found



NamespaceMismatch

Namespace mismatch

Fields

expected: String
found: String


DatabaseCorruption(String)

Database corruption detected



FileTruncated(String)

File truncated or incomplete



SlmNotAvailable

SLM feature not available (compiled without ‘slm’ feature)



SlmInitialization(String)

SLM initialization error



SlmInference(String)

SLM inference error



SlmTimeout(u64)

SLM timeout error



ModelNotFound(String)

Model file not found (entity extraction)



InferenceError(String)

Native inference error (llama.cpp)



EntityExtractionNotAvailable

Entity extraction feature not available



NoEmbeddingEngine

Embedding engine not configured — cannot auto-compute embeddings



EmbeddingNotAvailable

Embedding engine feature not available

Implementations

Source

impl Error

pub fn is_recoverable(&self) -> bool

Check if this error is recoverable

Recoverable errors can typically be retried or worked around. Non-recoverable errors indicate serious problems that require user intervention.

pub fn user_message(&self) -> String

Get a user-friendly error message with troubleshooting hints

pub fn is_corruption(&self) -> bool

Check if this is a corruption-related error

pub fn is_version_error(&self) -> bool

Check if this is a version-related error